## This is using the information from the MatrixLDA package. QUOTE:
#### - Handshapes: Files to create the handshapes dataset and perform the analyses. To create the handshapes dataset, download Set 1 from the Cambridge gestures database (ftp://mi.eng.cam.ac.uk/pub/CamGesData). The file Handshapes.txt contains the indices of images used in our dataset. The R script Conversion.R converts the raw images to greyscale. The matrix rescale.mat is the predictor. 
##
## Here we provide Handshapes.txt and take their conversion script.

# remotes::install_github('aoles/EBImage')
library(EBImage)
library(MixMatrix)
r = 80
s = 60

dat = array(0, dim = c(80,60,80))

filename = read.csv('Handshapes.txt', stringsAsFactors = FALSE, sep = " ")
# --- cd into directory containing images
#filename <- list.files()
for(j in 1:80){
	color.image = readImage(filename[j,1])
	bw.image = channel(color.image,"gray")
	bw.image = resize(bw.image, dim(bw.image)[1]/4)
    rescale.mat = matrix(bw.image, nrow=dim(bw.image)[1], ncol=dim(bw.image)[2])
    dat[,,j] = rescale.mat
	png(paste(filename[j,1],"__grey.png",sep=""), width=4, height=4, units="in", res=100)
	display(bw.image, method="raster")
	dev.off()
}


saveRDS(dat, 'hand-data.rds')
                                        # --- Using rescale.mat as predictors, create array using class codes in .txt file

#dat <- load('hand-data.rds')

classes = filename[,2]

test = rep(0,80)



X = dat
classX = classes


ARARmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "AR(1)", col.variance = "AR(1)",  method = "t")

CSCSmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "CS", col.variance = "CS",  method = "t")

UNconsmodel =  matrixqda(X, classX, c(.25,.25, .25,.25),  method = "t")

BIC(logLik(ARARmodel))
BIC(logLik(CSCSmodel))
BIC(logLik(UNconsmodel))


TARARmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "AR(1)", col.variance = "AR(1)", method = "t", nu = 20)

TCSCSmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "CS", col.variance = "CS", method = "t", nu = 20)

TUNconsmodel =  matrixqda(X, classX, c(.25,.25, .25,.25))


BIC(logLik(TARARmodel))
BIC(logLik(TCSCSmodel))
BIC(logLik(TUNconsmodel))


T5ARARmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "AR(1)", col.variance = "AR(1)", method = "t", nu = 5)

T5CSCSmodel = matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "CS", col.variance = "CS", method = "t", nu = 5)

#T5UNconsmodel =  matrixqda(X, classX, c(.25,.25, .25,.25))


BIC(logLik(T5ARARmodel))
BIC(logLik(T5CSCSmodel))
                                        #BIC(logLik(TUNconsmodel))


sum(predict(T5ARARmodel)$class == classes)

for( uu in 1:80){
X = dat[,,-uu]
classX = classes[-uu]
obsU = dat[,,uu, drop = FALSE]

test[uu] = (predict(matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "CS", col.variance = "CS",  method = "t"), newdata = obsU)$class == classes[uu])

}
sum(test)

write.csv(test,'hand-test-results-t-10.csv')


test = rep(0,80)

for( uu in 1:80){
X = dat[,,-uu]
classX = classes[-uu]
obsU = dat[,,uu, drop = FALSE]

test[uu] = (predict(matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "AR(1)", col.variance = "AR(1)",  method = "t", nu = 5), newdata = obsU)$class == classes[uu])

}
sum(test)

write.csv(test,'hand-test-results-t-5.csv')


###### This may hang and crash. 
test = rep(0,80)

for( uu in 1:80){
X = dat[,,-uu]
classX = classes[-uu]
obsU = dat[,,uu, drop = FALSE]

test[uu] = (predict(matrixqda(X, classX, c(.25,.25, .25,.25),row.variance = "AR(1)", col.variance = "AR(1)",  method = "normal", nu = 5), newdata = obsU)$class == classes[uu])

}
sum(test)

write.csv(test,'hand-test-results-normal.csv')
